{% extends "layout.html" %}
{% block content %}
<section class="hero">
    <section class="section">
        <div class="column is-4">
            <div class="card is-shady">
                <div class="card-image">
                    <figure class="image is-4by3">
                        <img src="https://unsplash.it/1200/600?{{ tx.hash }}" alt="
{{ tx.hash }}"/>
                    </figure>
                </div>
                <div class="card-content">
                    <div class="content">
                        <br>
                        <h4>Included in block: {{tx.height}}</h4>
                        <hr>
                        <div class="tags are-large">
                            <span class="tag are-large is-info">Transaction</span>
                            <span class="tag are-large is-warning">chain id: {{tx.tx.chain_id}}</span>
                        </div>
                        <br>
                        <div class="content" style="word-wrap: break-word;">
                            <p>Hash: {{tx.hash}}</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        </div>
    </section>
</section>
{% endblock %}
